# Security Policy

## Reporting a Vulnerability

**Please do not report security vulnerabilities through public GitHub issues.**

Instead, report security vulnerabilities by email to [`arcticdb@man.com`](mailto:arcticdb@man.com).

### Email content

Please include the requested information listed below (as much as you can provide) to help us better understand the nature and scope of the possible issue:

  * Type of issue (e.g. unsafe code, known vulnerabilities in dependencies, arbitrary code execution)
  * Full paths of the (source) file(s) related to the manifestation of the issue
  * The location of the affected source code (tag/branch/commit or direct URL)
  * The commit which introduced the vulnerability, if applicable
  * Any special configuration required to reproduce the issue
  * Step-by-step instructions to reproduce the issue
  * Proof-of-concept or exploit code (if possible)
  * Impact of the issue, including how an attacker might exploit the issue

Reporters will receive a response within 48 hours. If the vulnerability is confirmed, we will release a patch as soon as possible.

## Preferred Languages

We prefer all communications to be in English.
